@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,7 +54,9 @@
 
 namespace Avahi
 {
-  class PresencePublisher: public Ekiga::PresencePublisher
+  class PresencePublisher:
+    public Ekiga::Service,
+    public Ekiga::PresencePublisher
   {
 public:
 
@@ -64,6 +66,12 @@ public:
 
     ~PresencePublisher ();
 
+    const std::string get_name () const
+    { return "avahi-presence-publisher"; }
+
+    const std::string get_description () const
+    { return "\tObject bringing in Avahi presence publishing"; }
+
     void publish (const Ekiga::PersonalDetails & details);
 
     /* public only to be called by C callbacks... */
