@@ -48,6 +48,31 @@
 
 using namespace Opal;
 
+class CallSetup : public PThread
+{
+  PCLASSINFO(CallSetup, PThread);
+
+public:
+  CallSetup (Opal::Call & _call,
+             OpalConnection & _connection)
+    : PThread (1000, AutoDeleteThread),
+      call (_call),
+      connection (_connection)
+  {
+    this->Resume ();
+  }
+
+  void Main ()
+  {
+    call.DoSetUp (connection);
+  }
+
+private:
+  Opal::Call & call;
+  OpalConnection & connection;
+};
+
+
 Opal::Call::Call (OpalManager & _manager, Ekiga::ServiceCore & _core)
   : OpalCall (_manager), Ekiga::Call (), core (_core),
     call_setup(false),outgoing(true),jitter(0)
@@ -300,14 +325,12 @@ Opal::Call::parse_info (OpalConnection & connection)
   std::string r_party_name;
   std::string app;
 
+  remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
   if (!PIsDescendant(&connection, OpalPCSSConnection)) {
 
     outgoing = connection.IsOriginating ();
 
-    if (outgoing)
-      remote_uri = (const char *) connection.GetCall().GetPartyB ();
-    else
-      remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
+    remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
 
     l_party_name = (const char *) connection.GetCalledPartyURL ();
     r_party_name = (const char *) connection.GetRemotePartyName ();
@@ -521,7 +544,9 @@ Opal::Call::OnSetUp (OpalConnection & connection)
   cleared.connect (sigc::mem_fun (this, &Opal::Call::on_cleared_call));
   missed.connect (sigc::mem_fun (this, &Opal::Call::on_missed_call));
 
-  return OpalCall::OnSetUp (connection);
+  new CallSetup (*this, connection);
+
+  return true; 
 }
 
 
@@ -636,6 +661,13 @@ Opal::Call::OnRTPStatistics (const OpalConnection & /* connection */,
 }
 
 
+void
+Opal::Call::DoSetUp (OpalConnection & connection)
+{
+  OpalCall::OnSetUp (connection);
+}
+
+
 void
 Opal::Call::OnNoAnswerTimeout (PTimer &,
                                INT) 
