@@ -1,5 +1,5 @@
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2007 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 #include <stdint.h>
 #include "config.h"
 
-#include <ptlib/videoio.h>
+#include <ptlib.h>
 #include <ptlib/vconvert.h>
 
 #include <X11/Xlib.h>
